# Mixcloud RSS Feed Generator

Dieses Python-Script erstellt einen RSS-Feed aus deinen Mixcloud-Tracks, damit du sie über Podcast-Apps abonnieren und anhören kannst.

## Installation

1. Abhängigkeiten installieren:

   ```bash
   uv pip install -r requirements.txt
   ```

## Verwendung

### RSS-Feed erstellen

```bash
python mixcloud_rss.py serman_dj
```

Das erstellt eine `mixcloud_feed.xml` Datei mit deinen neuesten Mixcloud-Tracks.

### Erweiterte Optionen

```bash
# Feed mit 100 Tracks erstellen
python mixcloud_rss.py serman_dj --limit 100

# Feed in spezifische Datei speichern
python mixcloud_rss.py serman_dj --output mein_feed.xml

# HTTP-Server starten für den Feed
python mixcloud_rss.py serman_dj --serve

# Server auf anderem Port starten
python mixcloud_rss.py serman_dj --serve --port 8080
```

### RSS-Feed in Podcast-App hinzufügen

1. **Mit HTTP-Server (empfohlen):**
   - Starte den Server: `python mixcloud_rss.py serman_dj --serve`
   - Füge diese URL in deiner Podcast-App hinzu: `http://localhost:8000/mixcloud_feed.xml`

2. **Feed-Datei hosten:**
   - Lade die generierte XML-Datei auf einen Webserver hoch
   - Verwende die öffentliche URL in deiner Podcast-App

## Funktionen

- ✅ Holt automatisch deine neuesten Mixcloud-Tracks
- ✅ Erstellt RSS-Feed im Podcast-Format
- ✅ Unterstützt iTunes-Tags für bessere Kompatibilität
- ✅ Inkludiert Track-Metadaten (Titel, Beschreibung, Dauer, Tags)
- ✅ Eingebauter HTTP-Server zum Testen
- ✅ Konfigurierbare Anzahl von Tracks

## Bekannte Einschränkungen

**Audio-Streaming:** Mixcloud erlaubt kein direktes Audio-Streaming ohne Autorisierung. Die generierten Links verweisen auf die Mixcloud-Webseite. Für echtes Audio-Streaming müsste man:

1. Die offizielle Mixcloud API für Streaming verwenden
2. Oder eine Alternative wie yt-dlp für das Extrahieren der Audio-URLs nutzen

## Troubleshooting

### "Keine Cloudcasts gefunden"

- Überprüfe den Benutzernamen
- Stelle sicher, dass das Profil öffentlich ist

### RSS-Feed wird nicht in Podcast-App erkannt

- Überprüfe, ob der HTTP-Server läuft
- Teste die URL im Browser: `http://localhost:8000/mixcloud_feed.xml`

## Beispiel-Ausgabe

```text
Erstelle RSS-Feed für Mixcloud-User: serman_dj
RSS-Feed erfolgreich erstellt: mixcloud_feed.xml
Anzahl der Episoden: 50
```

## Automatisierung

Du kannst das Script regelmäßig ausführen lassen, um den Feed aktuell zu halten:

```bash
# Crontab-Eintrag für tägliche Updates um 6:00 Uhr
0 6 * * * cd /pfad/zu/rss-feeder && python mixcloud_rss.py serman_dj
```
